@@ -1,8 +1,6 @@
 package Moose::Exception::MethodNameNotGiven;
-BEGIN {
-  $Moose::Exception::MethodNameNotGiven::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::MethodNameNotGiven::VERSION = '2.1204';
+our $VERSION = '2.2203';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Class';
@@ -11,4 +9,5 @@ sub _build_message {
     "You must define a method name to find";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
